Reciprocal

Struct Reciprocal 

pub struct Reciprocal { /* private fields */ }
A pre-calculated reciprocal for division by a single limb.

Implementations

Source

impl Reciprocal

pub const fn ct_new(divisor: Limb) -> (Self, CtChoice)

Pre-calculates a reciprocal for a known divisor, to be used in the single-limb division later. Returns the reciprocal, and the truthy value if divisor != 0 and the falsy value otherwise.

Note: if the returned flag is falsy, the returned reciprocal object is still self-consistent and can be passed to functions here without causing them to panic, but the results are naturally not to be used.

pub const fn default() -> Self

Returns a default instance of this object. It is a self-consistent Reciprocal that will not cause panics in functions that take it.

NOTE: intended for using it as a placeholder during compile-time array generation, don’t rely on the contents.

pub fn new(divisor: Limb) -> CtOption<Self>

A non-const-fn version of new_const(), wrapping the result in a CtOption.